xygen
======

A Python module that generates xy coordinates for various geometric shapes. Pronounced ex-ee-gen.

Installation
------------

To install with pip, run:

    pip install xygen

Quickstart Guide
----------------

TODO - fill this in later

Contribute
----------

If you'd like to contribute to xygen, check out https://github.com/asweigart/xygen
